==> tmdy_dll_0.0.0-031121.zip: TiMidity++-2.12.0-pre1b-031117-0200/utils/net.c <==
/*
    TiMidity++ -- MIDI to WAVE converter and player
    Copyright (C) 1999-2002 Masanao Izumo <mo@goice.co.jp>
    Copyright (C) 1995 Tuukka Toivonen <tt@cgs.fi>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif /* HAVE_CONFIG_H */
#include <stdio.h>
#include <stdlib.h>
#if !defined(WINSOCK)
#include <unistd.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <netdb.h>
#include <arpa/inet.h>  /* for inet_ntoa */
#ifndef NO_STRING_H
#include <string.h>
#else
#include <strings.h>
#endif
#endif

#include "timidity.h"
#include "common.h"
#include "net.h"
#include "net_prv.h"

#ifndef INADDR_NONE
#define INADDR_NONE 0xffffffff
#endif /* INADDR_NONE */

#if !defined(WINSOCK)
#ifndef INVALID_SOCKET
#define INVALID_SOCKET -1
#endif /* INVALID_SOCKET */
#ifndef SOCKET_ERROR
#define SOCKET_ERROR -1
#endif /* SOCKET_ERROR */
#endif

SOCKET open_socket(tmdy_struct_ex_t *tmdy_struct, char *host, unsigned short port)
{
    SOCKET fd;
    struct sockaddr_in in;

#if defined(WINSOCK)
    static int open_socket_first = 1;
    if(open_socket_first) {
	WSADATA dmy;
	WSAStartup(MAKEWORD(1,1), &dmy);
	open_socket_first = 0;
    }
#endif

    memset(&in, 0, sizeof(in));
    if((in.sin_addr.s_addr = inet_addr(host)) == INADDR_NONE)
    {
	struct hostent *hp;
	if((hp = gethostbyname(host)) == NULL)
	    return (SOCKET)-1;
	memcpy(&in.sin_addr, hp->h_addr, hp->h_length);
    }
    in.sin_port = htons(port);
    in.sin_family = AF_INET;

    if((fd = socket(AF_INET, SOCK_STREAM, IPPROTO_TCP)) == INVALID_SOCKET)
	return (SOCKET)-1;

    if(connect(fd, (struct sockaddr *)&in, sizeof(in)) == SOCKET_ERROR)
    {
	closesocket(fd);
	return (SOCKET)-1;
    }

    return fd;
}

#if !defined(__W32__) || defined(__CYGWIN32__)
long socket_write(tmdy_struct_ex_t *tmdy_struct, SOCKET fd, char *buff, long bufsiz)
{
    return write(fd, buff, bufsiz);
}

int socket_shutdown(tmdy_struct_ex_t *tmdy_struct, SOCKET fd, int how)
{
    return shutdown(fd, how);
}

FILE *socket_fdopen(tmdy_struct_ex_t *tmdy_struct, SOCKET fd, char *mode)
{
    return fdopen(fd, mode);
}

char *socket_fgets(tmdy_struct_ex_t *tmdy_struct, char *buff, int n, FILE *fp)
{
    return fgets(buff, n, fp);
}

int socket_fgetc(tmdy_struct_ex_t *tmdy_struct, FILE *fp)
{
    return getc(fp);
}

long socket_fread(tmdy_struct_ex_t *tmdy_struct, void *buff, long bufsiz, FILE *fp)
{
    return (long)fread(buff, 1, bufsiz, fp);
}

long socket_fwrite(tmdy_struct_ex_t *tmdy_struct, void *buff, long bufsiz, FILE *fp)
{
    return (long)fwrite(buff, 1, bufsiz, fp);
}

int socket_fclose(tmdy_struct_ex_t *tmdy_struct, FILE *fp)
{
    return fclose(fp);
}

int socket_fflush(tmdy_struct_ex_t *tmdy_struct, FILE *fp)
{
    return fflush(fp);
}
#else /* __W32__ */

#include "url.h"

/* Fake FILE * */

typedef struct _w32_fp_socket_t
{
    SOCKET fd; /* Now, It has only fd */
} w32_fp_socket;
#define W32_FP2SOCKET(fp) (((w32_fp_socket *)(fp))->fd)

static long socket_safe_recv(tmdy_struct_ex_t *tmdy_struct, SOCKET fd, char *buff, long bufsiz)
{
    fd_set fds;
    int maxfd, n;

    FD_ZERO(&fds);
    FD_SET(fd, &fds);
    maxfd = fd + 1;

    n = select(maxfd, &fds, NULL, NULL, NULL);
    if(n <= 0)
	return n;
    return recv(fd, buff, bufsiz, 0);
}

long socket_write(tmdy_struct_ex_t *tmdy_struct, SOCKET fd, char *buff, long bufsiz)
{
    return send(fd, buff, bufsiz, 0);
}

int socket_shutdown(tmdy_struct_ex_t *tmdy_struct, SOCKET fd, int how)
{
    return shutdown(fd, how);
}

#pragma argsused
FILE *socket_fdopen(tmdy_struct_ex_t *tmdy_struct, SOCKET fd, char *mode)
{
    FILE *fp;

    /* w32_fp_socket fake FILE.
     * `mode' argument is ignored.
     */
    if((fp = (FILE *)TMDY_COMMON->safe_malloc(tmdy_struct, sizeof(w32_fp_socket))) == NULL)
	return NULL;
    memset(fp, 0, sizeof(w32_fp_socket));
    W32_FP2SOCKET(fp) = fd;
    return fp;
}

static int socket_getc(tmdy_struct_ex_t *tmdy_struct, SOCKET fd)
{
    int n;
    unsigned char c;
    
    n = socket_safe_recv(tmdy_struct, fd, (char *)&c, 1);
    if(n <= 0)
	return EOF;
    return (int)c;
}

char *socket_fgets(tmdy_struct_ex_t *tmdy_struct, char *buff, int n, FILE *fp)
{
    SOCKET fd = W32_FP2SOCKET(fp);
    int len;

    n--; /* for '\0' */
    if(n == 0)
	*buff = '\0';
    if(n <= 0)
	return buff;

    len = 0;
    while(len < n)
    {
	int c;
	c = socket_getc(tmdy_struct, fd);
	if(c == -1)
	    break;
	buff[len++] = c;
	if(c == *(TMDY_ARC->url->url_newline_code_p))
	    break;
    }
    if(len == 0)
	return NULL;
    buff[len] = '\0';
    return buff;
}

int socket_fgetc(tmdy_struct_ex_t *tmdy_struct, FILE *fp)
{
    SOCKET fd = W32_FP2SOCKET(fp);
    return socket_getc(tmdy_struct, fd);
}

long socket_fread(tmdy_struct_ex_t *tmdy_struct, void *buff, long bufsiz, FILE *fp)
{
    SOCKET fd = W32_FP2SOCKET(fp);
    return socket_safe_recv(tmdy_struct, fd, buff, bufsiz);
}

long socket_fwrite(tmdy_struct_ex_t *tmdy_struct, void *buff, long bufsiz, FILE *fp)
{
    SOCKET fd = W32_FP2SOCKET(fp);
    return socket_write(tmdy_struct, fd, buff, bufsiz);
}

int socket_fclose(tmdy_struct_ex_t *tmdy_struct, FILE *fp)
{
    SOCKET fd = W32_FP2SOCKET(fp);
    int ret;
    ret = closesocket(fd);
    free(fp);
    return ret;
}

int socket_fflush(tmdy_struct_ex_t *tmdy_struct, FILE *fp)
{
    return 0;
}
#endif



net_ex_t* new_net(tmdy_struct_ex_t *tmdy_struct){
	int i;
	net_ex_t* net_ex;

	net_ex=(net_ex_t *)malloc(sizeof(net_ex_t));
	
	timidity_mutex_init(net_ex->busy);		
	net_ex->open_socket=open_socket;
	net_ex->socket_shutdown=socket_shutdown;
	net_ex->socket_write=socket_write;
	net_ex->socket_fdopen=socket_fdopen;
	net_ex->socket_fgets=socket_fgets;
	net_ex->socket_fgetc=socket_fgetc;
	net_ex->socket_fread=socket_fread;
	net_ex->socket_fwrite=socket_fwrite;
	net_ex->socket_fflush=socket_fflush;
	net_ex->socket_fclose=socket_fclose;
	

	return net_ex;
}
void destroy_net(net_ex_t* net){
	timidity_mutex_destroy(net->busy);
	free(net);
}

==> tmdy_dll_0.0.0-031126.zip: TiMidity++-2.12.0-pre1b-031117-0200/utils/net.c <==
/*
    TiMidity++ -- MIDI to WAVE converter and player
    Copyright (C) 1999-2002 Masanao Izumo <mo@goice.co.jp>
    Copyright (C) 1995 Tuukka Toivonen <tt@cgs.fi>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif /* HAVE_CONFIG_H */
#include <stdio.h>
#include <stdlib.h>
#if !defined(WINSOCK)
#include <unistd.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <netdb.h>
#include <arpa/inet.h>  /* for inet_ntoa */
#ifndef NO_STRING_H
#include <string.h>
#else
#include <strings.h>
#endif
#endif

#include "timidity.h"
#include "common.h"
#include "net.h"
#include "net_prv.h"

#ifndef INADDR_NONE
#define INADDR_NONE 0xffffffff
#endif /* INADDR_NONE */

#if !defined(WINSOCK)
#ifndef INVALID_SOCKET
#define INVALID_SOCKET -1
#endif /* INVALID_SOCKET */
#ifndef SOCKET_ERROR
#define SOCKET_ERROR -1
#endif /* SOCKET_ERROR */
#endif

SOCKET open_socket(tmdy_struct_ex_t *tmdy_struct, char *host, unsigned short port)
{
    SOCKET fd;
    struct sockaddr_in in;

#if defined(WINSOCK)
    static int open_socket_first = 1;
    if(open_socket_first) {
	WSADATA dmy;
	WSAStartup(MAKEWORD(1,1), &dmy);
	open_socket_first = 0;
    }
#endif

    memset(&in, 0, sizeof(in));
    if((in.sin_addr.s_addr = inet_addr(host)) == INADDR_NONE)
    {
	struct hostent *hp;
	if((hp = gethostbyname(host)) == NULL)
	    return (SOCKET)-1;
	memcpy(&in.sin_addr, hp->h_addr, hp->h_length);
    }
    in.sin_port = htons(port);
    in.sin_family = AF_INET;

    if((fd = socket(AF_INET, SOCK_STREAM, IPPROTO_TCP)) == INVALID_SOCKET)
	return (SOCKET)-1;

    if(connect(fd, (struct sockaddr *)&in, sizeof(in)) == SOCKET_ERROR)
    {
	closesocket(fd);
	return (SOCKET)-1;
    }

    return fd;
}

#if !defined(__W32__) || defined(__CYGWIN32__)
long socket_write(tmdy_struct_ex_t *tmdy_struct, SOCKET fd, char *buff, long bufsiz)
{
    return write(fd, buff, bufsiz);
}

int socket_shutdown(tmdy_struct_ex_t *tmdy_struct, SOCKET fd, int how)
{
    return shutdown(fd, how);
}

FILE *socket_fdopen(tmdy_struct_ex_t *tmdy_struct, SOCKET fd, char *mode)
{
    return fdopen(fd, mode);
}

char *socket_fgets(tmdy_struct_ex_t *tmdy_struct, char *buff, int n, FILE *fp)
{
    return fgets(buff, n, fp);
}

int socket_fgetc(tmdy_struct_ex_t *tmdy_struct, FILE *fp)
{
    return getc(fp);
}

long socket_fread(tmdy_struct_ex_t *tmdy_struct, void *buff, long bufsiz, FILE *fp)
{
    return (long)fread(buff, 1, bufsiz, fp);
}

long socket_fwrite(tmdy_struct_ex_t *tmdy_struct, void *buff, long bufsiz, FILE *fp)
{
    return (long)fwrite(buff, 1, bufsiz, fp);
}

int socket_fclose(tmdy_struct_ex_t *tmdy_struct, FILE *fp)
{
    return fclose(fp);
}

int socket_fflush(tmdy_struct_ex_t *tmdy_struct, FILE *fp)
{
    return fflush(fp);
}
#else /* __W32__ */

#include "url.h"

/* Fake FILE * */

typedef struct s_w32_fp_socket_t
{
    SOCKET fd; /* Now, It has only fd */
} w32_fp_socket;
#define W32_FP2SOCKET(fp) (((w32_fp_socket *)(fp))->fd)

static long socket_safe_recv(tmdy_struct_ex_t *tmdy_struct, SOCKET fd, char *buff, long bufsiz)
{
    fd_set fds;
    int maxfd, n;

    FD_ZERO(&fds);
    FD_SET(fd, &fds);
    maxfd = fd + 1;

    n = select(maxfd, &fds, NULL, NULL, NULL);
    if(n <= 0)
	return n;
    return recv(fd, buff, bufsiz, 0);
}

long socket_write(tmdy_struct_ex_t *tmdy_struct, SOCKET fd, char *buff, long bufsiz)
{
    return send(fd, buff, bufsiz, 0);
}

int socket_shutdown(tmdy_struct_ex_t *tmdy_struct, SOCKET fd, int how)
{
    return shutdown(fd, how);
}

#pragma argsused
FILE *socket_fdopen(tmdy_struct_ex_t *tmdy_struct, SOCKET fd, char *mode)
{
    FILE *fp;

    /* w32_fp_socket fake FILE.
     * `mode' argument is ignored.
     */
    if((fp = (FILE *)TMDY_COMMON->safe_malloc(tmdy_struct, sizeof(w32_fp_socket))) == NULL)
	return NULL;
    memset(fp, 0, sizeof(w32_fp_socket));
    W32_FP2SOCKET(fp) = fd;
    return fp;
}

static int socket_getc(tmdy_struct_ex_t *tmdy_struct, SOCKET fd)
{
    int n;
    unsigned char c;
    
    n = socket_safe_recv(tmdy_struct, fd, (char *)&c, 1);
    if(n <= 0)
	return EOF;
    return (int)c;
}

char *socket_fgets(tmdy_struct_ex_t *tmdy_struct, char *buff, int n, FILE *fp)
{
    SOCKET fd = W32_FP2SOCKET(fp);
    int len;

    n--; /* for '\0' */
    if(n == 0)
	*buff = '\0';
    if(n <= 0)
	return buff;

    len = 0;
    while(len < n)
    {
	int c;
	c = socket_getc(tmdy_struct, fd);
	if(c == -1)
	    break;
	buff[len++] = c;
	if(c == *(TMDY_ARC->url->url_newline_code_p))
	    break;
    }
    if(len == 0)
	return NULL;
    buff[len] = '\0';
    return buff;
}

int socket_fgetc(tmdy_struct_ex_t *tmdy_struct, FILE *fp)
{
    SOCKET fd = W32_FP2SOCKET(fp);
    return socket_getc(tmdy_struct, fd);
}

long socket_fread(tmdy_struct_ex_t *tmdy_struct, void *buff, long bufsiz, FILE *fp)
{
    SOCKET fd = W32_FP2SOCKET(fp);
    return socket_safe_recv(tmdy_struct, fd, buff, bufsiz);
}

long socket_fwrite(tmdy_struct_ex_t *tmdy_struct, void *buff, long bufsiz, FILE *fp)
{
    SOCKET fd = W32_FP2SOCKET(fp);
    return socket_write(tmdy_struct, fd, buff, bufsiz);
}

int socket_fclose(tmdy_struct_ex_t *tmdy_struct, FILE *fp)
{
    SOCKET fd = W32_FP2SOCKET(fp);
    int ret;
    ret = closesocket(fd);
    free(fp);
    return ret;
}

int socket_fflush(tmdy_struct_ex_t *tmdy_struct, FILE *fp)
{
    return 0;
}
#endif



net_ex_t* new_net(tmdy_struct_ex_t *tmdy_struct){
	int i;
	net_ex_t* net_ex;

	net_ex=(net_ex_t *)malloc(sizeof(net_ex_t));
	
	timidity_mutex_init(net_ex->busy);		
	net_ex->open_socket=open_socket;
	net_ex->socket_shutdown=socket_shutdown;
	net_ex->socket_write=socket_write;
	net_ex->socket_fdopen=socket_fdopen;
	net_ex->socket_fgets=socket_fgets;
	net_ex->socket_fgetc=socket_fgetc;
	net_ex->socket_fread=socket_fread;
	net_ex->socket_fwrite=socket_fwrite;
	net_ex->socket_fflush=socket_fflush;
	net_ex->socket_fclose=socket_fclose;
	

	return net_ex;
}
void destroy_net(net_ex_t* net){
	timidity_mutex_destroy(net->busy);
	free(net);
}
